Python Module Index — Numina 0.20.dev0 documentation

# Python Module Index

a | c | d | e | f | l | m | n | s | t | u | v

| a |
| `numina.array` | Array manipulation
| `numina.array.background` |
| `numina.array.blocks` |
| `numina.array.bpm` |
| `numina.array.cosmetics` | Array cosmetics
| `numina.array.fwhm` |
| `numina.array.imsurfit` | Image surface fitting
| `numina.array.interpolation` |
| `numina.array.mode` |
| `numina.array.nirproc` | nIR preprocessing
| `numina.array.offrot` |
| `numina.array.peaks` |
| `numina.array.recenter` |
| `numina.array.robustfit` |
| `numina.array.stats` |
| `numina.array.utils` |
| `numina.array.wavecalib.arccalibration` |
| `numina.array.wavecalib.peaks_spectrum` |
| `numina.array.wavecalib.solutionarc` |
| c |
| `numina.core` |
| `numina.core.dataholders` |
| `numina.core.metaclass` |
| `numina.core.metarecipes` |
| `numina.core.oresult` |
| `numina.core.pipeline` |
| `numina.core.pipelineload` |
| `numina.core.qc` | Quality Control for Numina
| `numina.core.recipeinout` | Base classes for Recipe Requirements and Results
| `numina.core.recipes` | Base classes for Recipes
| `numina.core.requirements` |
| `numina.core.taggers` |
| `numina.core.types` |
| `numina.core.utils` |
| `numina.core.validator` |
| d |
| `numina.dal` |
| `numina.dal.absdal` |
| `numina.dal.backend` |
| `numina.dal.daliface` |
| `numina.dal.dictdal` |
| `numina.dal.diskfiledal` |
| `numina.dal.mockdal` |
| `numina.dal.stored` |
| `numina.dal.utils` |
| `numina.datamodel` |
| `numina.drps` |
| `numina.drps.drpbase` |
| `numina.drps.drpsystem` |
| e |
| `numina.exceptions` | Numina exceptions
| f |
| `numina.frame` | Frame manipulation
| `numina.frame.schema` | Schema for FITS header
| l |
| `numina.logger` | TBD
| m |
| `numina.modeling` |
| `numina.modeling.enclosed` |
| `numina.modeling.gaussbox` |
| `numina.modeling.sumofgauss` |
| n |
| `numina` |
| s |
| `numina.store` |
| t |
| `numina.treedict` | TBD
| `numina.types` | TBD
| `numina.types.array` | TBD
| `numina.types.base` | TBD
| `numina.types.dataframe` | TBD
| `numina.types.datatype` | TBD
| `numina.types.frame` | TBD
| `numina.types.linescatalog` | TBD
| `numina.types.multitype` | TBD
| `numina.types.qc` | Quality Control for Numina
| `numina.types.structured` | TBD
| u |
| `numina.user` | User command line interface for Numina
| `numina.user.xdgdirs` | TBD
| `numina.util` | TBD
| `numina.util.flow` | TBD
| `numina.util.objimport` |
| v |
| `numina.visualization` | TBD